"""
Canonical visualization and data processing libraries
Use PEP8 or Google style docstrings if going to prod
"""
import matplotlib.pyplot as plt
import pandas as pd
import prophet
import streamlit as st

import lib.snowflake_utils as su

conn = su.init_connection()

cs = conn.cursor()
m = prophet.Prophet(daily_seasonality=True)

try:
    cs.execute("SELECT DATE, SALES FROM MODEL_DATA;")
    df = pd.DataFrame(cs.fetchall(), columns = ['DATE', 'SALES'])

    df['ds'] = pd.to_datetime(df['DATE'])
    df['y'] = df['SALES']

    # Split the data into TRAINING and TEST sets
    train = df[df['ds'] > pd.Timestamp('2015-12-31')]
    test = df[df['ds'] >= pd.Timestamp('2016-03-23')]

    m.fit(train)

    # For future versions, user should be able to select
    # periods ahead for the forecast
    future = m.make_future_dataframe(periods=15)
    forecast = m.predict(future)

    fig_m = m.plot(forecast)
    plt.legend(['Actual', 'Prediction', 'Uncertainty interval'])
    
    fig_c = m.plot_components(forecast)
    st.write(fig_c)

    # Total aggregates for forecast_start = 2016-03-24
    # In the PoC, only grab (TEST + 1) day-ahead - first day of forecast
    cs.execute("""select "forecast_start", "MAPE", "sMAPE" from evaluation_metrics where "TARGET"='Total';""")
    df_0 = pd.DataFrame(cs.fetchall(), columns=["forecast_start", "MAPE", "sMAPE"])

    fig, ax = plt.subplots()
    ax.bar(df_0['forecast_start'], df_0['MAPE'], label='MAPE')
    ax.bar(df_0['forecast_start'], df_0['MAPE'], bottom=df_0['sMAPE'], label='sMAPE')
    ax.set_xlabel('Date')
    ax.set_ylabel('Value')
    ax.set_title('Total Performance Metrics')
    ax.legend()

    st.pyplot(fig)

finally:
    cs.close()
cs.close()
