"""
Basic database connectivity to interface with Streamlit,
along with useful admin libraries
"""
from datetime import datetime, timedelta
import time
import snowflake.connector
import streamlit as st

# Hard-coded; need to be parameterized for code-based
# usage monitoring
# Define the start and end times for the monitoring period
start_time = datetime.now()
end_time = start_time + timedelta(hours=8)

# Define the query to monitor warehouse usage (automatically detects which one to target based on connectivity)
query = f"SELECT COUNT(*) FROM table(INFORMATION_SCHEMA.WAREHOUSE_METERING_HISTORY(start_time=>'{start_time}', end_time=>'{end_time}'))"

# Define the interval between checks (in seconds?)
interval = 60

# Parameterize and run in the main loop of the app
while datetime.now() < end_time:
    # Execute the query to get the current warehouse usage
    cur = conn.cursor()
    cur.execute(query)
    result = cur.fetchone()

    # Print the current warehouse usage
    print(f"Current warehouse usage: {result[0]} credits")

    # Wait for the specified interval before checking again
    time.sleep(interval)

# Open / Close the Snowflake connection
# conn.close()

@st.cache_resource
def init_connection():
    """
    Establishes a connection to a Snowflake database using credentials stored in `st.secrets`.
    Caches the connection using `@st.cache_resource` decorator for reuse across function calls.

    Returns:
        Connector object for a database connection with `client_session_keep_alive` set to `True`.
    """
    return snowflake.connector.connect(
        **st.secrets["snowflake"], client_session_keep_alive=True
    )
