import pandas as pd
import snowflake.snowpark.functions as F
from dateutil.relativedelta import relativedelta
from src.holiday_events import EventFactory


def model(dbt, session):
    # dbt configuration
    dbt.config(packages=["pandas"])
    session.add_import(
        "src/holiday_events.py",
        import_path="src.holiday_events"
        )

    date_col = "DATE"

    # get upstream data
    df = dbt.ref("WALMART_current")
    df = df.with_column(date_col, F.to_date(F.col(date_col)))

    # Calculate date range:
    date_range = df.agg(
        F.min(F.col(date_col)).alias("min_date"),
        F.max(F.col(date_col)).alias("max_date"),
    ).to_pandas()

    factory = EventFactory(
        country="US",
        date_col=date_col,
        min_date=date_range["MIN_DATE"][0],
        max_date=date_range["MAX_DATE"][0] + relativedelta(years=1),
    )

    return factory.generate(
        lower_window=3, upper_window=1, add_special=True
    ).to_pandas()
