import snowflake.snowpark.functions as F
import pandas as pd
import numpy as np
from dateutil.relativedelta import relativedelta

def model(dbt, session):
    dbt.config(
        packages = ['pandas', 'numpy'],
        materialized = "table",
        tags = "data-split"
    )

    date_col = "DATE"
    target_col = "SALES"

    # get table:
    df = dbt.ref("dim_food")
    features = [
        dbt.source("DATASCIENCE_FEATURES", "CALENDAR_FEATURES"),
        dbt.source("DATASCIENCE_FEATURES", "HOLIDAY_FEATURES")
        ]

    # Filter data:
    data = df.filter((F.col("DEPT_ID") == "FOODS_1") & (F.col(date_col) > "2013-01-01")).to_pandas()
    data[target_col] = data[target_col].astype(int)
    x = (
        data.query(f"{target_col} > 0").groupby("ID").size()
        / data.groupby("ID").size().unique()
    )
    data_filt = data[data.ID.isin(x[x > 0.5].index)]

    # Join tables:
    data_joined = pd.merge(
        data_filt,
        features[0].to_pandas(),
        on=date_col,
    )
    data_joined = pd.merge(
        data_joined,
        features[1].to_pandas()[
            [date_col, "time_to_next_event", "time_since_last_event"]
            ],
        on=date_col,
    )

    # Split data:
    data_joined[date_col] = pd.to_datetime(data_joined[date_col])
    first_date = data_joined[date_col].max() - relativedelta(months=2)
    out = data_joined.assign(
        **{
            "DATA_SPLIT": np.where(
                data_joined[date_col] <= first_date,
                "TRAIN",
                "TEST",
            )
        }
    )

    # Convert date fied:
    out = out.assign(**{date_col: out[date_col].astype(str)})

    return out

