import snowflake.snowpark.functions as F
import pandas as pd
import numpy as np
from sklearn.preprocessing import LabelEncoder


def filter_by_prevalence(df, target_col, id_col, prevalence = 0.8):
    counts = (df.filter(F.col(target_col) > 0).group_by(id_col).count().with_column_renamed(F.col("COUNT"), "COUNTnn"))
    lengths = df.group_by(id_col).count()
    df_info = counts.join(lengths, on=id_col).with_column("PROP", (F.col("COUNTNN")/F.col("COUNT")))
    df_sample = (
        df.join(
            df_info.filter(F.col("PROP") >= prevalence),
            how="inner",
            on=id_col,
        )
        .drop(["COUNT", "COUNTNN", "PROP"])
    )
    return df_sample


def model(dbt, session):
    dbt.config(
        packages = ['pandas', 'numpy', 'scikit-learn'],
        materialized = "table",
        tags = ["data-prep", "sample"]
    )

    # Load data:
    df = dbt.ref("model_data")

    # Sample data:
    first_date = '2015-01-01'
    date_col = "DATE"
    target_col = "SALES"
    id_col = "ID"

    df = df.filter(F.col(date_col) >= first_date)
    df_sample = filter_by_prevalence(
        df=df,
        target_col=target_col, 
        id_col=id_col, 
        prevalence=0.8,
    ).to_pandas()

    cat_cols = ['ITEM_ID', 'STATE_ID', 'STORE_ID']
    for col in cat_cols:
        df_sample[col] = LabelEncoder().fit_transform(df_sample[col])
    
    drop_cols = ["CAT_ID", "DEPT_ID"]
    
    return df_sample.drop(drop_cols, axis=1)