from src.utils import load_config
from snowflake.snowpark.session import Session
import snowflake.snowpark.functions as F
import numpy as np

config = load_config("config/snowpark_transformer_config.yml")

# Establish Snowpark session:
session = Session.builder.configs(config).create()

session.get_current_schema()
session.get_current_database()
[s.name for s in session.sql("SHOW VIEWS;").collect()]

# Get target table as Snowpark dataframe:
df = session.table("WALMART_CURRENT")
df.show()

# Convert date-field to datetime:
df.withColumn(
    F.col("DATE"), F.to_date(F.col("DATE"), "yyyy-mm-dd").alias("DATE")
)
df = df.with_column("DATE", F.to_date(F.col("DATE")))

# Add date features ---
# Date of year:
df = df.with_column("DAYOFYEAR", F.dayofyear(F.col("DATE")))
# Date as sine wave:
df = df.with_column(
    "DATESINE",
    F.round(F.sin(F.lit(2 * np.pi) * F.col("DAYOFYEAR") / F.lit(365)), 3),
)

df.show()
