from snowflake.snowpark.session import Session
import snowflake.snowpark.functions as F
import snowflake.snowpark.types as T

import yaml
import pandas as pd
import polars as pl

# (1) Start session ---
# Read connection parameters:
with open("config/snowpark_config.yml") as f:
    config = yaml.load(f, Loader=yaml.loader.SafeLoader)

config

# Establish Snowpark session:
session = Session.builder.configs(config).create()

session.sql("SHOW OBJECTS;").collect()

# (2) Create objects ---
# Create a Virtual Warehouse:
session.sql(
    """
    create or replace warehouse FT_FORECASTING_WH with
    warehouse_size='X-SMALL'
    auto_suspend = 180
    auto_resume = true
    initially_suspended=true;
    """
).collect()
session.sql("SELECT CURRENT_WAREHOUSE();").collect()

# Create Databse:
session.sql("CREATE OR REPLACE DATABASE FT_FORECASTING_DEMO_DB").collect()
session.sql("SELECT CURRENT_DATABASE();").collect()

# (3) Upload data ---
# Loading from local file:
df = pl.read_parquet("data/m5/sales.parquet")

# Upload to Snowflake:
sdf = df.sample(1000000).to_pandas()

session.write_pandas(
    df=sdf,
    table_name="LANDING_sales_data",
    auto_create_table=True,
    overwrite=True,
    parallel=8,
    chunk_size=10000,
)

session.sql("SHOW OBJECTS;").collect()
